@@ -278,3 +278,17 @@ void PuntateMain::on_stream17_clicked()
     process.start("sh /opt/serviziopubblico/script/p17.sh");
     process.waitForFinished();
 }
+
+void PuntateMain::on_down18_clicked()
+{
+    QProcess process;
+    process.start("sh /opt/serviziopubblico/script/d18.sh");
+    process.waitForFinished();
+}
+
+void PuntateMain::on_stream18_clicked()
+{
+    QProcess process;
+    process.start("sh /opt/serviziopubblico/script/p18.sh");
+    process.waitForFinished();
+}
