@@ -88,6 +88,10 @@ private slots:
 
     void on_stream17_clicked();
 
+    void on_down18_clicked();
+
+    void on_stream18_clicked();
+
 private:
     Ui::PuntateMain *ui;
 };
